﻿using System;
using System.Drawing;
using System.Drawing.Printing;
using System.Windows.Media;
using C1.C1Preview;
using NUnit.Framework;

namespace TestProject
{
    public class Tests
    {

        [Test]
        public void MissingFontsExportTest([Values("C:\\Temp")] string outputPath, [Values(100)] int amountOfExports)
        {

            for (int index = 0; index < amountOfExports; index++)
            {
                var md = new C1MultiDocument();

                var printDoc = CreateDoc();
                AddTable(printDoc);
                md.Items.Add(printDoc);

                md.Generate();
                md.Export($"{outputPath}{index}.pdf");
            }
        }


        private void AddTable(C1PrintDocument c1PrintDocument)
        {
            var header = CreateHeaderTemplate();
            header.Cells[0, 0].RenderObject = GenerateHeaderCell("Car Model", "Audi A6");
            
            c1PrintDocument.PageLayouts.Default.PageHeader = header;
        }

        private RenderTable CreateHeaderTemplate()
        {
            var header = CreateTable();

            header.Style.GridLines.All = new LineDef(new Unit(0.2, UnitTypeEnum.Mm), Colors.Black, System.Drawing.Drawing2D.DashStyle.Solid);
            header.CellStyle.Padding.All = new Unit(0.5, UnitTypeEnum.Mm);
            header.Cols[0].Width = new Unit(35, UnitTypeEnum.Mm);
            header.Cols[1].Width = new Unit(35, UnitTypeEnum.Mm);
            header.Cols[2].Width = new Unit(50, UnitTypeEnum.Mm);
            header.Cols[3].Width = new Unit(64, UnitTypeEnum.Mm);

            header.Cells[0, 3].SpanRows = 2;
            header.Cells[2, 1].SpanCols = 2;
            header.Cells[3, 1].SpanCols = 2;
            return header;
        }


        private RenderTable GenerateHeaderCell(String description, String text)
        {
            var cellTable = CreateTable();

            cellTable.Cells[0, 0].RenderObject = new RenderText(description, new Font("Arial", 6, GraphicsUnit.Point));
            cellTable.Cells[1, 0].RenderObject = new RenderText(text, new Font("Courier New", 9, GraphicsUnit.Point), AlignHorzEnum.Center);

            return cellTable;
        }


        private RenderTable CreateTable()
        {
            var table = new RenderTable();

            table.SplitVertBehavior = SplitBehaviorEnum.SplitNewPage;
            table.CellStyle.Padding.All = new Unit(0.5, UnitTypeEnum.Mm);
            table.Width = new Unit(177, UnitTypeEnum.Mm);

            return table;
        }


        private C1PrintDocument CreateDoc()
        {
            C1PrintDocument.UsePrinterForDefaultPageSettings = false;

            var doc = new C1PrintDocument();
            doc.FontHandling = FontHandling.EmbedFonts;
            doc.CreationDpi = 200;
            doc.Style.Font = new Font("Courier New", 9, GraphicsUnit.Point);
            doc.PageLayouts.Default.PageSettings.PaperKind = PaperKind.A4;
            doc.PageLayouts.Default.PageSettings.TopMargin = new Unit(0.5, UnitTypeEnum.Cm);
            doc.PageLayouts.Default.PageSettings.BottomMargin = new Unit(1, UnitTypeEnum.Cm);
            doc.PageLayouts.Default.PageSettings.LeftMargin = new Unit(2, UnitTypeEnum.Cm);
            doc.PageLayouts.Default.PageSettings.RightMargin = new Unit(1.3, UnitTypeEnum.Cm);

            var cr = new RenderText();
            cr.Width = new Unit(1, UnitTypeEnum.Cm);
            cr.Text = "Overlay text";
            cr.Style.FontSize = 4;
            cr.Style.FontBold = true;
            cr.Style.TextAlignHorz = AlignHorzEnum.Left;
            cr.Style.TextAngle = 90;
            cr.X = new Unit(0.3, UnitTypeEnum.Cm);
            cr.Y = new Unit(20, UnitTypeEnum.Cm);
            
            doc.PageLayouts.Default.Overlay = cr;

            return doc;
        }
    }
}